@@ -28,8 +28,8 @@ print $out;
 exit 0;
 
 __END__
---- usrc/uuid/gen_uuid.c	Mon Feb  6 22:31:29 2023
-+++ usrcP/uuid/gen_uuid.c	Tue Dec 26 03:23:21 2023
+--- usrc/uuid/gen_uuid.c	Wed Nov 29 23:03:41 2023
++++ usrcP/uuid/gen_uuid.c	Wed Dec  6 02:28:10 2023
 @@ -112,7 +112,7 @@
  THREAD_LOCAL unsigned short jrand_seed[3];
  #endif
@@ -39,7 +39,7 @@ __END__
  {
  	struct timeval	tv;
  	static int	fd = -2;
-@@ -149,7 +149,7 @@
+@@ -154,7 +154,7 @@
   * Generate a series of random bytes.  Use /dev/urandom if possible,
   * and if not, use srandom/random.
   */
@@ -48,7 +48,7 @@ __END__
  {
  	int i, n = nbytes, fd;
  	int lose_counter = 0;
-@@ -165,7 +165,7 @@
+@@ -170,7 +170,7 @@
  		return;
  #endif
  
@@ -57,7 +57,7 @@ __END__
  	if (fd >= 0) {
  		while (n > 0) {
  			i = read(fd, cp, n);
-@@ -210,7 +210,7 @@
+@@ -215,7 +215,7 @@
   * commenting out get_node_id just to get gen_uuid to compile under windows
   * is not the right way to go!
   */
@@ -66,7 +66,7 @@ __END__
  {
  #ifdef HAVE_NET_IF_H
  	int 		sd;
-@@ -295,19 +295,19 @@
+@@ -300,19 +300,19 @@
  /* Assume that the gettimeofday() has microsecond granularity */
  #define MAX_ADJUSTMENT 10
  
@@ -90,7 +90,7 @@ __END__
  	mode_t				save_umask;
  	int				len;
  
-@@ -356,7 +356,7 @@
+@@ -361,7 +361,7 @@
  	}
  
  	if ((last.tv_sec == 0) && (last.tv_usec == 0)) {
@@ -99,7 +99,7 @@ __END__
  		clock_seq &= 0x3FFF;
  		gettimeofday(&last, 0);
  		last.tv_sec--;
-@@ -381,8 +381,8 @@
+@@ -386,8 +386,8 @@
  	}
  
  	clock_reg = tv.tv_usec*10 + adjustment;
@@ -110,7 +110,7 @@ __END__
  
  	if (num && (*num > 1)) {
  		adjustment += *num - 1;
-@@ -420,7 +420,7 @@
+@@ -425,7 +425,7 @@
  }
  
  #if defined(USE_UUIDD) && defined(HAVE_SYS_UN_H)
@@ -119,7 +119,7 @@ __END__
  {
  	ssize_t ret;
  	ssize_t c = 0;
-@@ -447,7 +447,7 @@
+@@ -452,7 +452,7 @@
  /*
   * Close all file descriptors
   */
@@ -128,7 +128,7 @@ __END__
  {
  	int i, max;
  
-@@ -483,14 +483,14 @@
+@@ -488,14 +488,14 @@
   *
   * Returns 0 on success, non-zero on failure.
   */
@@ -145,7 +145,7 @@ __END__
  	struct sockaddr_un srv_addr;
  	struct stat st;
  	pid_t pid;
-@@ -564,16 +564,16 @@
+@@ -569,16 +569,16 @@
  #pragma GCC diagnostic pop
  #endif
  
@@ -167,7 +167,7 @@ __END__
  			/*
  			 * Set multicast bit, to prevent conflicts
  			 * with IEEE 802 addresses obtained from
-@@ -583,19 +583,19 @@
+@@ -588,19 +588,19 @@
  		}
  		has_init = 1;
  	}
@@ -192,7 +192,7 @@ __END__
  	THREAD_LOCAL time_t		last_time = 0;
  	time_t				now;
  
-@@ -606,10 +606,10 @@
+@@ -611,10 +611,10 @@
  	}
  	if (num <= 0) {
  		num = 1000;
@@ -205,7 +205,7 @@ __END__
  			num--;
  			return;
  		}
-@@ -623,22 +623,22 @@
+@@ -628,22 +628,22 @@
  				uu.time_hi_and_version++;
  		}
  		num--;
@@ -234,7 +234,7 @@ __END__
  	int i, n;
  
  	if (!num || !*num)
-@@ -647,23 +647,23 @@
+@@ -652,23 +652,23 @@
  		n = *num;
  
  	for (i = 0; i < n; i++) {
@@ -264,7 +264,7 @@ __END__
  }
  
  
-@@ -673,10 +673,10 @@
+@@ -678,10 +678,10 @@
   * /dev/urandom is available, since otherwise we won't have
   * high-quality randomness.
   */
